@@ -136,6 +136,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_lambda
@@ -159,8 +161,8 @@ class SnsToLambda(
         *,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -174,6 +176,10 @@ class SnsToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the LambdaToSns class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SnsToLambdaProps(
             existing_lambda_obj=existing_lambda_obj,
             existing_topic_obj=existing_topic_obj,
@@ -210,8 +216,8 @@ class SnsToLambdaProps:
         *,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
@@ -225,6 +231,12 @@ class SnsToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsToLambdaProps.__init__)
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
